Index: ChangeLog
from  Alexandre Oliva  <oliva@dcc.unicamp.br>
	
	* nnmail.el (nnmail-split-fancy): Document RESTRICT clauses.
	(nnmail-split-it): Implement them.
	
Index: nnmail.el
===================================================================
RCS file: /home/phd/oliva/src/.cvs/src/emacs-lisp/nnmail.el,v
retrieving revision 1.1.1.2.2.2
diff -u -r1.1.1.2.2.2 nnmail.el
--- nnmail.el	1999/07/05 00:32:29	1.1.1.2.2.2
+++ nnmail.el	1999/07/05 01:44:03
@@ -293,8 +293,12 @@
 
 GROUP: Mail will be stored in GROUP (a string).
 
-\(FIELD VALUE SPLIT): If the message field FIELD (a regexp) contains
-  VALUE (a regexp), store the messages as specified by SPLIT.
+\(FIELD VALUE [- RESTRICT [- RESTRICT [...]]] SPLIT): If the message
+  field FIELD (a regexp) contains VALUE (a regexp), store the messages 
+  as specified by SPLIT.  If RESTRICT (a regexp) matches some string
+  after FIELD and before the end of the matched VALUE, return NIL,
+  otherwise process SPLIT.  Multiple RESTRICTs add up, further
+  restricting the possibility of processing SPLIT.
 
 \(| SPLIT...): Process each SPLIT expression until one of them matches.
   A SPLIT expression is said to match if it will cause the mail
@@ -337,6 +341,13 @@
 	     ;; Other mailing lists...
 	     (any \"procmail@informatik\\\\.rwth-aachen\\\\.de\" \"procmail.list\")
 	     (any \"SmartList@informatik\\\\.rwth-aachen\\\\.de\" \"SmartList.list\")
+             ;; Both lists below have the same suffix, so prevent
+             ;; cross-posting to mkpkg.list of messages posted only to 
+             ;; the bugs- list, but allow cross-posting when the
+             ;; message was really cross-posted.
+             (any \"bugs-mypackage@somewhere\" \"mypkg.bugs\")
+             (any \"mypackage@somewhere\" - \"bugs-mypackage\" \"mypkg.list\")
+             ;; 
 	     ;; People...
 	     (any \"larsi@ifi\\\\.uio\\\\.no\" \"people.Lars Magne Ingebrigtsen\"))
 	  ;; Unmatched mail goes to the catch all group.
@@ -1128,15 +1139,36 @@
       (when (re-search-backward (cdr cached-pair) nil t)
 	(when nnmail-split-tracing
 	  (push (cdr cached-pair) nnmail-split-trace))
-	;; Someone might want to do a \N sub on this match, so get the
-	;; correct match positions.
-	(goto-char (match-end 0))
-	(let ((value (nth 1 split)))
-	  (re-search-backward (if (symbolp value)
-				  (cdr (assq value nnmail-split-abbrev-alist))
-				value)
-			      (match-end 1)))
-	(nnmail-split-it (nth 2 split))))
+	(let ((split-rest (cddr split))
+	      (end (match-end 0))
+	      ;; The searched regexp is \(\(FIELD\).*\)\(VALUE\).  So,
+	      ;; start-of-value is the the point just before the
+	      ;; beginning of the value, whereas after-header-name is
+	      ;; the point just after the field name.
+	      (start-of-value (match-end 1))
+	      (after-header-name (match-end 2)))
+	  ;; Handle - RESTRICTs
+	  (while (eq (car split-rest) '-)
+	    ;; RESTRICT must start after-header-name and
+	    ;; end after start-of-value, so that, for
+	    ;; (any "foo" - "x-foo" "foo.list")
+	    ;; we do not exclude foo.list just because
+	    ;; the header is: ``To: x-foo, foo''
+	    (goto-char end)
+	    (if (and (re-search-backward (cadr split-rest)
+					 after-header-name t)
+		     (> (match-end 0) start-of-value))
+		(setq split-rest nil)
+	      (setq split-rest (cddr split-rest))))
+	  (when split-rest
+	    (goto-char end)
+	    (let ((value (nth 1 split)))
+	      (if (symbolp value)
+		  (setq value (cdr (assq value nnmail-split-abbrev-alist))))
+	      ;; Someone might want to do a \N sub on this match, so get the
+	      ;; correct match positions.
+	      (re-search-backward value start-of-value))
+	    (nnmail-split-it (car split-rest))))))
 
      ;; Not in cache, compute a regexp for the field/value pair.
      (t
